# Tutorials

Here is a list of tutorials to help you learn how to use Metanno.

For a deeper understanding of the framework, check out the [Pret tutorials](https://percevalw.github.io/pret/main/tutorials/).

<!-- --8<-- [start:tutorials] -->

=== card {: href=/tutorials/new-project/ }

    :fontawesome-solid-plus:
    **Set up a new project**

    ---
    Learn how to install Metanno in a new project or add it to an existing one.

=== card {: href=/tutorials/run-quaero-explorer/ }

    :fontawesome-solid-gear:
    **Run the Data Explorer demo**

    ---
    Run the Quaero Explorer demo app and discover its features: persisting annotations, collaborating, and more.

=== card {: href=/tutorials/customize-explorer/ }

    :fontawesome-solid-robot:
    **Customize the Data Explorer**

    ---
    Learn how to pre-annotate entities using EDS-NLP and annotate higher-level structures in the Data Explorer.

<!--
=== card {: href=/tutorials/byo-dataframe-annotator/ }

    :fontawesome-solid-code:
    **Build a dataframe annotator**

    ---
    Build a custom annotator that uses a dataframe as the data source.
-->

<!-- --8<-- [end:tutorials] -->
